@@ -1,5 +1,5 @@
 package FIAS::SQL;
-$FIAS::SQL::VERSION = '0.03';
+$FIAS::SQL::VERSION = '0.04';
 # ABSTRACT: Модуль для минимальной работы с данными из базы ФИАC https://fias.nalog.ru/FiasInfo.aspx
 
 use strict;
@@ -19,25 +19,25 @@ use v5.10;
 # Условно выделены следующие уровни адресных объектов:
 Readonly our $LEVELS => {
    # 1 – уровень региона
-   region                    => 1,
+   region                    => '1',
    # 3 – уровень района
-   district                  => 3,
+   district                  => '3',
    # 35 – уровень городских и сельских поселений
-   settlement => 35,
+   settlement => '35',
    # 4 – уровень города
-   town                      => 4,
+   town                      => '4',
    # 6 – уровень населенного пункта
-   inhabitet_locality        => 6,
+   inhabitet_locality        => '6',
    # 65 – планировочная структура
-   planning_structure        => 65,
+   planning_structure        => '65',
    # 7 – уровень улицы
-   street                    => 7,
+   street                    => '7',
    # 75 – земельный участок
-   stead                     => 75,
+   stead                     => '75',
    # 8 – здания, сооружения, объекта незавершенного строительства
-   structure                 => 8,
+   structure                 => '8',
    # 9 – уровень помещения в пределах здания, сооружения
-   premises                  => 95
+   premises                  => '9'
 };
 
 sub new {
@@ -478,7 +478,7 @@ FIAS::SQL - Модуль для минимальной работы с данн
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
     # Создание объекта, подключение к базе
     my  $fias = FIAS::SQL->new(
